#ifndef ENEMY_H
#define ENEMY_H

#include <vector>
#include <string>

#include "utility.h"

enum class position{front, back, side};

enum class turnState{move, attack};


class Enemy {
	
	protected:
		
		
		int current_hp, max_hp;
		int current_ap, max_ap;
		int exp_value;
		
		int protection, attack_power;
		
	public:
	
		vec2 current_position, screen_position;
		int frontSprite, sideSprite, backSprite;
		position player_orientation;
		std::string name;
		bool alive;
		int orientation;
		turnState current_state;

		virtual bool APUsage() = 0;
		virtual void Initialize(int x, int y, int hp_max, int ap_max, int value, int front, int side, int back, int protect, int attack, std::string newName) = 0;
		virtual int basic_attack() = 0;
		bool TakeDamage(int damage)
		{
			current_hp -= (damage - protection);
			if (current_hp<=0)
			{
				alive = false;
				return true;
			}
			else
			{
				return false;
			}
		}
		
		int ReturnAP()
		{
			return current_ap;
		}
		
		bool Move(direction target_direction)
		{
			switch (target_direction)
			{
				case direction::up:
					orientation = 1;
					current_position.y--;
				break;
				
				case direction::down:
					orientation = 0;
					current_position.y++;
				break;
				
				case direction::left:
					orientation = 2;
					current_position.x--;
				break;
				
				case direction::right:
					orientation = 3;
					current_position.x++;
				break;
			}
			
			current_ap--;
			
			if (current_ap<=0)
			{
				current_ap = max_ap;
				return true;
			}
			
			return false;
				
		}
		
	
	
};

class Slime: public Enemy {
	
	public:
	
		int basic_attack(){
			
			int damage=0;
			
			damage=attack_power;
			
			current_ap--;
			
			return damage;
			
		}
		
		void Initialize(int x, int y, int hp_max, int ap_max, int value, int front, int side, int back, int protect, int attack, std::string newName){
			
			current_state = turnState::move;
			
			alive = true;
			
			current_position.x = x;
			current_position.y = y;
			
			max_hp = hp_max;
			current_hp = max_hp;
			
			max_ap = ap_max;
			current_ap = max_ap;
			
			exp_value = value;
			
			frontSprite = front;
			sideSprite = side;
			backSprite = back;
			
			protection = protect;
			attack_power = attack;
			
			name = newName;
			
		}
		
		bool APUsage()
		{
			current_ap--;
			
			if (current_ap == 0)
			{
				current_ap = max_ap;
				return true;
			}
			else
			{
				return false;
			}
		}
	
};



#endif /* ENEMY_H */