#include "gamecontrol.h"

void GameControl::AgbMain2(int length_value, int frequency_value){ 
	//turn on sound circuit
	REG_SOUNDCNT_X = 0x80;
	
	//full volume, enable sound 2 to left and right
	REG_SOUNDCNT_L=0x2277;
	
	// Overall output ratio - Full
	REG_SOUNDCNT_H = 2;

	REG_SOUND2CNT_L=length_value; //0x0f?80 - ? is note length value
	REG_SOUND2CNT_H=frequency_value; //frequency determined by 0x8???, loop mode

}

void GameControl::PlayMusic(const playNote musicArray[]){

	int pitchNum=0;
	unsigned short freq;

	if (numSyncs==reqSyncs){
			if (musicArray[currentNote].notepitch!=""){ 
				for (int i=0;i<72;i++){
					if (notes[i].pitch==musicArray[currentNote].notepitch){
						freq=notes[i].frequency;
						break;
					}
				}
				AgbMain2((0xf080+(256*musicArray[currentNote].notelength)),(0x8000+freq));
			}
			
			numSyncs=0;
			reqSyncs=(10+(musicArray[currentNote].notelength*musicSpeed));
			
			currentNote++;
			
			if (currentNote>=musicLength){
				currentNote=0;
			}
	}
}

void GameControl::SetLoadedSquareTile(int screenblock, int x, int y, int tileNum){
	
	SetTile(screenblock, x, y, tileNum);
	SetTile(screenblock, x+1, y, tileNum+1);
	SetTile(screenblock, x, y+1, tileNum+16);
	SetTile(screenblock, x+1, y+1, tileNum+17);
	
}

void GameControl::SetBlankTile(int screenblock, int x, int y)
{
	SetTile(screenblock, x, y, 14);
	SetTile(screenblock, x+1, y, 14);
	SetTile(screenblock, x, y+1, 14);
	SetTile(screenblock, x+1, y+1, 14);
}

bool GameControl::CheckWorldCollision(Floor &currentFloor, int targetX, int targetY)
{
	if (currentFloor.baseTileMap[targetX][targetY] == 1 || currentFloor.baseTileMap[targetX][targetY] == 7){
		return false;
	}
	else {
		return true;
	}
}

void GameControl::Initialize()
{
	REG_DISPCNT = DCNT_MODE0 | DCNT_BG0| DCNT_BG1| DCNT_BG2 | DCNT_BG3 | DCNT_OBJ;
	REG_BG0CNT = BG_CBB(0) | BG_SBB(29) | BG_8BPP | BG_REG_32x32 | BG_PRIO(2);
	REG_BG1CNT = BG_CBB(0) | BG_SBB(30) | BG_8BPP | BG_REG_32x32 | BG_PRIO(3);
	REG_BG2CNT = BG_CBB(2) | BG_SBB(28) | BG_8BPP | BG_REG_32x32 | BG_PRIO(1);
	REG_BG3CNT = BG_CBB(1) | BG_SBB(27) | BG_8BPP | BG_REG_32x32 | BG_PRIO(0);
	
	LoadPaletteBGData(0, basicdungeontilePal, sizeof basicdungeontilePal);
	LoadTileData(0, 0, basicdungeontileTiles, sizeof basicdungeontileTiles);
	
	for (int i = 0; i<10; i++)
	{
		LoadTile8(2, i, UITiles[i]);
	}
	
	SetPaletteBG(49, RGB(5,3,0));
	
	LoadPaletteObjData(0, spritesheetPal, sizeof spritesheetPal);
	LoadTileData(4, 0, spritesheetTiles, sizeof spritesheetTiles);
	
	for (int i = 0; i<128; i++){
		LoadTile8(1, i, font_bold[i]);
	}
	
	for (int x=0;x<30;x++){
		for (int y=0;y<20;y++){
			SetTile(28, x, y, 17);
			lightMap[x][y]=0;
		}
	}
	
	//SetBGPalette();
	
	musicSpeed=8;
	orientation = 0;
	numSyncs=0;
	reqSyncs=0;
	currentNote=0;
	reverse = false;
	playerTurn = true;
	currentEnemy = 0;
	menuOpen=false;
	list_position = 0;
	
}

void GameControl::PlayerHandler(uint16_t currentKeys, player_character &player, Floor &currentFloor)
{
	if ((currentKeys&KEY_LEFT)==0)
	{
		ClearUI();
		MoveManager(currentFloor, player, direction::left);
	}
	else if ((currentKeys&KEY_RIGHT)==0)
	{
		ClearUI();
		MoveManager(currentFloor, player, direction::right);
	}
	
	if ((currentKeys&KEY_R)==0)
	{
		ClearUI();
		if (player.TORCH_EQUIPPED==true){
			player.TORCH_EQUIPPED=false;
		}
		else{
			player.TORCH_EQUIPPED=true;
		}
		
		for (int x=8; x<21;x+=2){
			for (int y=4;y<17;y+=2){
				lightMap[x][y]=0;
			}
		}
	}
	
	if ((currentKeys&KEY_UP)==0)
	{
		ClearUI();
		MoveManager(currentFloor, player, direction::up);
	}
	else if ((currentKeys&KEY_DOWN)==0){
		ClearUI();
		MoveManager(currentFloor, player, direction::down);
	}

	if ((currentKeys&KEY_A)==0)
	{
		ClearUI();
		targetEnemy = 99;
		
		switch (player.target_direction)
		{
			case direction::up:
					
							for (int i=0; i<currentFloor.enemy_list.size(); i++)
							{
								
								storeX = currentFloor.enemy_list[i]->current_position.x;
								storeY = currentFloor.enemy_list[i]->current_position.y;
									
								if (storeX == player.current_position.x)
								{
									if (storeY == (player.current_position.y-1)&&currentFloor.enemy_list[i]->alive == true)
									{
										targetEnemy = i;
									}
								}

							}

			break;
			
			case direction::down:
					
							for (int i=0; i<currentFloor.enemy_list.size(); i++)
							{
								
								storeX = currentFloor.enemy_list[i]->current_position.x;
								storeY = currentFloor.enemy_list[i]->current_position.y;
									
								if (storeX == player.current_position.x)
								{
									if (storeY == (player.current_position.y+1)&&currentFloor.enemy_list[i]->alive == true)
									{
										targetEnemy = i;
									}
								}

							}

			break;
			
			case direction::left:
					
							for (int i=0; i<currentFloor.enemy_list.size(); i++)
							{
								
								storeX = currentFloor.enemy_list[i]->current_position.x;
								storeY = currentFloor.enemy_list[i]->current_position.y;
									
								if (storeX == (player.current_position.x-1))
								{
									if (storeY == player.current_position.y &&currentFloor.enemy_list[i]->alive == true)
									{
										targetEnemy = i;
									}
								}
							}

			break;
			
			case direction::right:
					
							for (int i=0; i<currentFloor.enemy_list.size(); i++)
							{
								
								storeX = currentFloor.enemy_list[i]->current_position.x;
								storeY = currentFloor.enemy_list[i]->current_position.y;
									
								if (storeX == (player.current_position.x+1))
								{
									if (storeY == player.current_position.y &&currentFloor.enemy_list[i]->alive == true)
									{
										targetEnemy = i;
									}
								}

							}

					
			break;
		}
		
		DrawUIBox(4, 15, 20, 3);

		if (targetEnemy != 99)
		{
			int damaged = player.ReturnAttack();
			char damageRead[23];
			sprintf(damageRead, "You dealt %d damage!", damaged);
			DrawText(5, 16, damageRead);
			
			if(currentFloor.enemy_list[targetEnemy]->TakeDamage(damaged))
			{
				//15
				DrawText(5, 17, "You killed the ");
				DrawText(5, 18, currentFloor.enemy_list[targetEnemy]->name.c_str());
			}
			
		}
		else
		{
			DrawText(5, 16, "You missed!");
		}

		player.ap--;							
	}
	
	
	if (player.current_position.x == currentFloor.stairLocation.x && player.current_position.y == currentFloor.stairLocation.y)
	{
		DrawUIBox(4, 15, 20, 3);
		DrawText(5, 16, "You reached the exit!");
	}
	
	if (player.ap <= 0)
	{
		playerTurn = false;
		player.ap = player.MAX_AP;
	}
}

void GameControl::MoveManager(Floor &currentFloor, player_character &player, direction target_direction)
{
	
	int targetX, targetY;
	
	switch (target_direction){
		
		case direction::up: targetX = player.current_position.x;
							targetY = player.current_position.y-1;
							orientation = 2;
							break;
		
		case direction::down: targetX = player.current_position.x;
							targetY = player.current_position.y+1;
							orientation = 0;
							break;
							
		case direction::left: targetX = player.current_position.x-1;
							targetY = player.current_position.y;
							orientation = 1;
							FlipObjectHorizontal(0, false);
							break;
		
		case direction::right: targetX = player.current_position.x+1;
							targetY = player.current_position.y;
							orientation = 1;
							FlipObjectHorizontal(0, true);
							break;
	}
	
	player.target_direction=target_direction;
	
	if (!CheckWorldCollision(currentFloor, targetX, targetY))
	{
		player.MOVE(target_direction);
		
	}
}

void GameControl::EnemyHandler(player_character &player, Floor &currentFloor)
{
	if (currentFloor.enemy_list[currentEnemy]->alive == true)
	{
		
		switch (currentFloor.enemy_list[currentEnemy]->current_state)
		{
			case turnState::move:
			
				int distTop, distBot, distLeft, distRight;
				direction target_direction;
				vec2 target_tile;
				
				distTop = (currentFloor.enemy_list[currentEnemy]->current_position.y - (player.current_position.y-1))+(currentFloor.enemy_list[currentEnemy]->current_position.x - player.current_position.x);
				distBot = (currentFloor.enemy_list[currentEnemy]->current_position.y - (player.current_position.y+1))+(currentFloor.enemy_list[currentEnemy]->current_position.x - player.current_position.x);
				distLeft = (currentFloor.enemy_list[currentEnemy]->current_position.y - player.current_position.y)+(currentFloor.enemy_list[currentEnemy]->current_position.x - (player.current_position.x-1));
				distRight = (currentFloor.enemy_list[currentEnemy]->current_position.y - player.current_position.y)+(currentFloor.enemy_list[currentEnemy]->current_position.x - (player.current_position.x+1));
				
				
				if (std::min(distTop, std::min(distBot, std::min(distLeft, distRight))) == distTop)
				{
					target_tile.x = player.current_position.x;
					target_tile.y = player.current_position.y-1;
				}
				else if (std::min(distTop, std::min(distBot, std::min(distLeft, distRight))) == distBot)
				{
					target_tile.x = player.current_position.x;
					target_tile.y = player.current_position.y+1;
				}
				else if (std::min(distTop, std::min(distBot, std::min(distLeft, distRight))) == distLeft)
				{
					target_tile.x = player.current_position.x-1;
					target_tile.y = player.current_position.y;
				}
				else
				{
					target_tile.x = player.current_position.x+1;
					target_tile.y = player.current_position.y;
				}
				
				if (currentFloor.enemy_list[currentEnemy]->current_position.y > target_tile.y)
				{
					target_direction = direction::up;
				}
				else if (currentFloor.enemy_list[currentEnemy]->current_position.y < target_tile.y)
				{
					target_direction = direction::down;
				}
				else if (currentFloor.enemy_list[currentEnemy]->current_position.x > target_tile.x)
				{
					target_direction = direction::left;
				}
				else if (currentFloor.enemy_list[currentEnemy]->current_position.x < target_tile.x)
				{
					target_direction = direction::right;
				}
				else
				{
					currentFloor.enemy_list[currentEnemy]->current_state = turnState::attack;
				}
				
				if (currentFloor.enemy_list[currentEnemy]->current_state == turnState::move)
				{
					if (currentFloor.enemy_list[currentEnemy]->Move(target_direction))
					{
						currentEnemy++;
						if (currentEnemy++ >= currentFloor.enemy_list.size())
						{
							currentEnemy = 0;
							playerTurn = true;
						}
					}
				}
						
			break;
			
			case turnState::attack:
			
				if (currentFloor.enemy_list[currentEnemy]->current_position.x < (player.current_position.x-1) 
						|| currentFloor.enemy_list[currentEnemy]->current_position.x > (player.current_position.x+1) 
							|| currentFloor.enemy_list[currentEnemy]->current_position.y < (player.current_position.y-1)
								||currentFloor.enemy_list[currentEnemy]->current_position.y > (player.current_position.y+1))
								{
									currentFloor.enemy_list[currentEnemy]->current_state = turnState::move;
								}
								else
								{
									
									DrawUIBox(2, 15, 23, 3);
									int damaged = currentFloor.enemy_list[currentEnemy]->basic_attack();
									char damageRead[27];
									sprintf(damageRead, "The foe dealt %d damage!", damaged);
									DrawText(3, 16, damageRead);
									
									if (player.TakeDamage(damaged))
									{
										DrawText(5, 17, "You were defeated!");
									}
									
									if (currentFloor.enemy_list[currentEnemy]->ReturnAP()<=0)
									{
										currentEnemy++;
										if (currentEnemy++ >= currentFloor.enemy_list.size())
										{
											currentEnemy = 0;
											playerTurn = true;
										}
									}
									
									
								}
			
			break;
		}
	}
	else
	{
		currentEnemy++;
		if (currentEnemy++ >= currentFloor.enemy_list.size())
		{
			currentEnemy = 0;
			playerTurn = true;
		}
	}
}


void GameControl::CalculateLightMap(player_character &player)
{
	if (player.TORCH_EQUIPPED==true){
			for (int y=4;y<17;y+=2){
				if (y==4||y==16){
					for (int x=12;x<17;x+=2){
						lightMap[x][y]=1;
					}
				}
				else if (y==6||y==14){
					for (int x=10;x<19;x+=2){
						lightMap[x][y]=1;
					}
				}
				else if (y==8||y==12){
					for (int x=8;x<21;x+=2){
						lightMap[x][y]=1;
					}
				}
				else if (y==10){
					for (int x=8;x<21;x+=2){
						lightMap[x][y]=1;
					}
				}
			}
		}
		else {
			for (int y=6;y<15;y+=2){

				if (y==6||y==14){
					for (int x=12;x<17;x+=2){
						lightMap[x][y]=1;
					}
				}
				else if (y==8||y==12){
					for (int x=10;x<19;x+=2){
						lightMap[x][y]=1;
					}
				}
				else if (y==10){
					for (int x=10;x<19;x+=2){
						lightMap[x][y]=1;
					}
				}
			}
		}			
}

void GameControl::RenderUI(player_character &player, Floor &current_floor)
{
	
			//Draw HP
			SetTile(27, 0, 0, (48+player.hp/10));
			SetTile(27, 1, 0, (48+player.hp%10));
			SetTile(27, 2, 0, 47);
			SetTile(27, 3, 0, (48+player.MAX_HP/10));
			SetTile(27, 4, 0, (48+player.MAX_HP%10));

			//Draw AP
			SetTile(27, 0, 2, (48+player.ap/10));
			SetTile(27, 1, 2, (48+player.ap%10));
		
						
}

void GameControl::DrawText(int x,int y,const char string[]){
	
	int i=0;
	
	while (string[i]!='\0'){
		SetTile(27,x+i,y,string[i]);
		i++;
	}
	
}

void GameControl::OpenMenu()
{
	if (menuOpen == true)
	{
		menuOpen = false;
		for (int x = 0; x<30; x++)
		{
			for (int y = 0; y<20; y++)
			{
				SetTile(28, x, y, 14);
				SetTile(27, x, y, 0);
			}
		}
	}
	else
	{
		menuOpen = true;
		current_menu = menuState::ability;
	//	menu_position = menuState::ability;
	}
}

void GameControl::ClearUI()
{
	for (int x = 0; x<30; x++)
	{
		for (int y = 0; y<20; y++)
		{
			SetTile(28, x, y, 14);
			SetTile(27, x, y, 0);
		}
	}
}

void GameControl::DrawUIBox(int startX, int startY, int sizeX, int sizeY)
{
	//Draw UI Box
	SetTile(28, startX, startY, 0);
	for (int x = (startX+1); x<(startX+1+sizeX); x++)
	{
		SetTile(28, x, startY, 1);
	}
	SetTile(28, (startX+1+sizeX), startY, 2);
	
	for (int y = (startY+1); y<(startY+1+sizeY); y++)
	{
		SetTile(28, startX, y, 3);
		for (int x = (startX+1); x<(startX+1+sizeX); x++)
		{
			SetTile(28, x, y, 4);
		}
		SetTile(28, (startX+1+sizeX), y, 5);
	}
	
	SetTile(28, startX, (startY+sizeY+1), 6);
	for (int x = (startX+1); x<(startX+1+sizeX); x++)
	{
		SetTile(28, x, (startY+sizeY+1), 7);
	}
	SetTile(28, (startX+sizeX+1), (startY+sizeY+1), 8);
}

void GameControl::MenuHandler(uint16_t currentKeys, player_character &player, Floor &currentFloor)
{
	switch (current_menu)
	{
		case menuState::main: 
			
			break;
		
		case menuState::ability:
			
			DrawUIBox(20, 10, 7, player.ability_list.size());
			
			for (int y = 11; y<(11+(player.ability_list.size())); y++)
			{
				DrawText(22, y, player.ability_list[y-11]->name.c_str());
			}
			
			SetTile(27, 21, (11+list_position), 3);
			
			if ((currentKeys&KEY_UP)==0)
			{
				SetTile(27, 21, (11+list_position), 0);
				
				if (list_position>0)
				{
					list_position--;
				}
			}
			else if ((currentKeys&KEY_DOWN)==0)
			{
				SetTile(27, 21, (11+list_position), 0);
				
				if (list_position<player.ability_list.size())
				{
					list_position++;
				}
			}
			
			if ((currentKeys&KEY_A)==0)
			{
				targetEnemy = 99;
				
				switch (player.target_direction)
				{
					case direction::up:
							
							for (int y = 0; y<player.ability_list[list_position]->range; y++)
							{
								if (targetEnemy == 99 )
								{
									for (int i=0; i<currentFloor.enemy_list.size(); i++)
									{
										
										storeX = currentFloor.enemy_list[i]->current_position.x;
										storeY = currentFloor.enemy_list[i]->current_position.y;
											
										if (storeX == player.current_position.x)
										{
											if (storeY == ((player.current_position.y-1)-y)&&currentFloor.enemy_list[i]->alive == true)
											{
												targetEnemy = i;
											}
										}

									}
								}
							}
	
					break;
					
					case direction::down:
							
							for (int y = 0; y<player.ability_list[list_position]->range; y++)
							{
								if (targetEnemy == 99)
								{
									for (int i=0; i<currentFloor.enemy_list.size(); i++)
									{
										
										storeX = currentFloor.enemy_list[i]->current_position.x;
										storeY = currentFloor.enemy_list[i]->current_position.y;
											
										if (storeX == player.current_position.x)
										{
											if (storeY == ((player.current_position.y+1)+y)&&currentFloor.enemy_list[i]->alive == true)
											{
												targetEnemy = i;
											}
										}

									}
								}
							}
	
					break;
					
					case direction::left:
							
							for (int x = 0; x<player.ability_list[list_position]->range; x++)
							{
								if (targetEnemy == 99 )
								{
									for (int i=0; i<currentFloor.enemy_list.size(); i++)
									{
										
										storeX = currentFloor.enemy_list[i]->current_position.x;
										storeY = currentFloor.enemy_list[i]->current_position.y;
											
										if (storeX == ((player.current_position.x-1)-x))
										{
											if (storeY == player.current_position.y &&currentFloor.enemy_list[i]->alive == true)
											{
												targetEnemy = i;
											}
										}

									}
								}
							}
	
					break;
					
					case direction::right:
							
							for (int x = 0; x<player.ability_list[list_position]->range; x++)
							{
								if (targetEnemy == 99 )
								{
									for (int i=0; i<currentFloor.enemy_list.size(); i++)
									{
										
										storeX = currentFloor.enemy_list[i]->current_position.x;
										storeY = currentFloor.enemy_list[i]->current_position.y;
											
										if (storeX == ((player.current_position.x+1)+x))
										{
											if (storeY == player.current_position.y &&currentFloor.enemy_list[i]->alive == true)
											{
												targetEnemy = i;
											}
										}

									}
								}
							}
							
					break;
				}
				
				OpenMenu();
				
				DrawUIBox(4, 15, 20, 3);
				
				if (targetEnemy != 99)
				{
					int damaged = player.USE_ABILITY(list_position);
					char damageRead[23];
					sprintf(damageRead, "You dealt %d damage!", damaged);
					DrawText(5, 16, damageRead);
					
					if(currentFloor.enemy_list[targetEnemy]->TakeDamage(damaged))
					{
						DrawText(5, 17, "You killed the ");
						DrawText(5, 18, currentFloor.enemy_list[targetEnemy]->name.c_str());
					}
					
				}
				else
				{
					DrawText(5, 16, "You missed!");
				}
				

											
			}
			
			break;
			
		case menuState::item:
		
			break;
	}
}

void GameControl::RenderWorld(Floor &currentFloor, int playerX, int playerY)
{
	
	for (int x=0;x<30;x+=2){
			for (int y=0;y<20;y+=2){
				
				if (lightMap[x][y]!=1){
					SetLoadedSquareTile(29,x,y,12);
				}
				else {
					SetBlankTile(29,x,y);
				}
				
				if (currentFloor.baseTileMap[(x/2)+(playerX)][(y/2)+(playerY)]==1){
					SetLoadedSquareTile(30,x,y,0);
				}
				else if (currentFloor.baseTileMap[(x/2)+(playerX)][(y/2)+(playerY)]==2){
					SetLoadedSquareTile(30,x,y,10);
				}
				else if (currentFloor.baseTileMap[(x/2)+(playerX)][(y/2)+(playerY)]==3){
					SetLoadedSquareTile(30,x,y,2);
				}
				else if (currentFloor.baseTileMap[(x/2)+(playerX)][(y/2)+(playerY)]==4){
					SetLoadedSquareTile(30,x,y,4);
				}
				else if (currentFloor.baseTileMap[(x/2)+(playerX)][(y/2)+(playerY)]==5){
					SetLoadedSquareTile(30,x,y,6);
				}
				else if (currentFloor.baseTileMap[(x/2)+(playerX)][(y/2)+(playerY)]==6){
					SetLoadedSquareTile(30,x,y,8);
				}
				else if (currentFloor.baseTileMap[(x/2)+(playerX)][(y/2)+(playerY)]==7){
					SetLoadedSquareTile(30,x,y,14);
				}
				else {
					SetLoadedSquareTile(30,x,y,40);
				}
			}
		}
		
}

void GameControl::RenderPlayer(player_character &player)
{
	if(orientation==0)
	{
		if(reverse==false)
		{
			SetObjectSprite(0, player.frontSprite);
		}
		else
		{
			SetObjectSprite(0, player.frontSprite+2);
		}
	}
	else if(orientation == 1)
	{
		if(reverse==false)
		{
			SetObjectSprite(0, player.sideSprite);
		}
		else
		{
			SetObjectSprite(0, player.sideSprite+2);

		}
	}
	else
	{
		if(reverse==false)
		{
			SetObjectSprite(0, player.backSprite);

		}
		else
		{
			SetObjectSprite(0, player.backSprite+2);
		}
	}
		
}

void GameControl::RenderEnemies(Floor &currentFloor, player_character &player)
{
	for (int i = 0; i<currentFloor.enemy_list.size(); i++)
	{
		currentFloor.enemy_list[i]->screen_position = WorldToScreenPos(currentFloor.enemy_list[i]->current_position, player.draw_position);
			
		if (currentFloor.enemy_list[i]->screen_position.x<=14 && currentFloor.enemy_list[i]->screen_position.x>=0 && currentFloor.enemy_list[i]->screen_position.y<=9 && currentFloor.enemy_list[i]->screen_position.y>=0 && currentFloor.enemy_list[i]->alive == true){
			if (lightMap[currentFloor.enemy_list[i]->screen_position.x][currentFloor.enemy_list[i]->screen_position.y]==0)
			{
				SetObjectX(i+1, currentFloor.enemy_list[i]->screen_position.x*16);
				SetObjectY(i+1, currentFloor.enemy_list[i]->screen_position.y*16);
				ShowObject(i+1);
				switch (currentFloor.enemy_list[i]->orientation)
				{
					case 0:
						if(reverse==false)
						{
							SetObjectSprite(i+1, currentFloor.enemy_list[i]->frontSprite);
						}
						else
						{
							SetObjectSprite(i+1, currentFloor.enemy_list[i]->frontSprite+2);
						}
					break;
					
					case 1:
						if(reverse==false)
						{
							SetObjectSprite(i+1, currentFloor.enemy_list[i]->backSprite);
						}
						else
						{
							SetObjectSprite(i+1, currentFloor.enemy_list[i]->backSprite+2);
						}
						
					break;
					
					case 2:
					
						FlipObjectHorizontal(i+1, false);
						if(reverse==false)
						{
							SetObjectSprite(i+1, currentFloor.enemy_list[i]->sideSprite);
						}
						else
						{
							SetObjectSprite(i+1, currentFloor.enemy_list[i]->sideSprite+2);
						}
						
					break;
					
					case 3:
					
						FlipObjectHorizontal(i + 1, true);
						if(reverse==false)
						{
							SetObjectSprite(i+1, currentFloor.enemy_list[i]->sideSprite);
						}
						else
						{
							SetObjectSprite(i+1, currentFloor.enemy_list[i]->sideSprite+2);
						}
						
					break;
				}
					
			}
			else
			{
				HideObject(i+1);
			}
		}
		else
		{
			HideObject(i+1);
		}
	}
	
	if (reverse == true) {
		reverse = false;
	}
	else
	{
		reverse = true;
		
	}
}