#ifndef GAMECONTROL_H
#define GAMECONTROL_H

#include <stdio.h>
#include <algorithm>

#include "gba.h"
#include "dungeon.h"
#include "player.h"
#include "notes.h"
#include "music.h"
#include "tiles/basicdungeontile.h"
#include "tiles/spritesheet.h"
#include "UITiles.h"
#include "font.h"
#include "utility.h"


enum class menuState{main, ability, item};

class GameControl
{
	private:
		
		menuState current_menu;
		menuState menu_position;
		uint8_t list_position;
		int storeX, storeY;
		int targetEnemy;
		int musicSpeed;
		int orientation;
		int reqSyncs;
		int currentNote;
		bool reverse;
		void SetLoadedSquareTile(int screenblock, int x, int y, int tileNum);
		void SetBlankTile(int screenblock, int x, int y);
		bool CheckWorldCollision(Floor &currentFloor, int targetX, int targetY);
		void AgbMain2(int length_value, int frequency_value);
		void DrawText(int x,int y,const char string[]);
		void ClearUI();
		void DrawUIBox(int startX, int startY, int sizeX, int sizeY);
		
	public:
	
		uint8_t lightMap[30][20];
		int numSyncs;
		int currentEnemy;
		bool playerTurn;
		bool menuOpen;
		
		void Initialize();
		void MenuHandler(uint16_t currentKeys, player_character &player, Floor &currentFloor);
		void MoveManager(Floor &currentFloor, player_character &player, direction target_direction);
		void PlayerHandler(uint16_t currentKeys, player_character &player, Floor &currentFloor);
		void EnemyHandler(player_character &player, Floor &currentFloor);
		void CalculateLightMap(player_character &player);
		void RenderPlayer(player_character &player);
		void RenderEnemies(Floor &currentFloor, player_character &player);
		void RenderUI(player_character &player, Floor &current_floor);
		void RenderWorld(Floor &currentFloor, int playerX, int playerY);
		void PlayMusic(const playNote musicArray[]);
		void OpenMenu();
		
};

#endif