#include "player.h"

player_character::player_character(int strength, int dexterity, int willpower, int vitality, int protection, int attack){
	STR=strength;
	DEX=dexterity;
	WILL=willpower;
	VIT=vitality;
	base_protection=protection;
	base_attack=attack;
}

int player_character::ReturnAttack()
{
	return attack;
}

void player_character::Initialize(std::vector<Weapon> &weapon_list, std::vector<Armour> &armour_list, std::vector<Trinket> &trinket_list){
	
	character_class = "Warrior";
	
	MAX_AP = 2;
	ap = MAX_AP;
	
	item_storage tempItem;
	
	tempItem.itemName = "Shortsword";
	tempItem.itemType = "Weapon";
	tempItem.itemWeight= 1;
	
	Add_Item(tempItem);
	
	tempItem.itemName = "Iron Armour";
	tempItem.itemType = "Armour";
	tempItem.itemWeight= 1;
	
	Add_Item(tempItem);
	
	weapon = "Shortsword";
	armour =  "Iron Armour";
	
	ADD_ABILITY(new Cleave());
	ability_list[0]->Initialize(1, 2, 2, 1, "Cleave");
	
	CALC_MAX_HP(weapon_list, armour_list, trinket_list);
	CALC_MAX_CARRY(weapon_list, armour_list, trinket_list);
	CALC_PROTECTION(weapon_list, armour_list, trinket_list);
	CALC_ATTACK(weapon_list, armour_list, trinket_list);
	
	hp = MAX_HP;
	
	TORCH_EQUIPPED=true;
	
	frontSprite = 0;
	sideSprite = 4;
	backSprite = 8;
	
	current_position.x = 5;
	current_position.y = 1;
	
	draw_position.x = current_position.x-7;
	draw_position.y = current_position.y-5;
	
}

bool player_character::TakeDamage(int damage)
{
	if (damage-protection>0)
	{
		hp -= (damage - protection);
	}
	else
	{
		hp--;
	}
	
	if (hp <= 0)
	{
		hp=0;
		return true;
	}
	
	return false;
}

void player_character::Add_Item(item_storage item){
	
	if (carry<=MAX_CARRY-item.itemWeight)
	{
		carry+=item.itemWeight;
		item_list.push_back(item);
	}
		
}

void player_character::CALC_MAX_HP(std::vector<Weapon> &weapon_list, std::vector<Armour> &armour_list, std::vector<Trinket> &trinket_list){
	
	int VIT_MODIFIER=0;
	
	if (weapon!=""){
		for (uint16_t i=0; i<weapon_list.size();i++){
			if (weapon_list[i].name==weapon){
				VIT_MODIFIER+=weapon_list[i].VIT_MODIFIER;
				break;
			}
		}
	}
	
	if (armour!=""){
		for (uint16_t i=0; i<armour_list.size();i++){
			if (armour_list[i].name==armour){
				VIT_MODIFIER+=armour_list[i].VIT_MODIFIER;
				break;
			}
		}
	}
	
	if (trinket!=""){
		for (uint16_t i=0; i<trinket_list.size(); i++){
			if (trinket_list[i].name==trinket){
				VIT_MODIFIER+=trinket_list[i].VIT_MODIFIER;
				break;
			}
		}
	}
	
	MAX_HP=(VIT+VIT_MODIFIER)*10;
	
	if (weapon!=""){
		for (uint16_t i=0; i<weapon_list.size();i++){
			if (weapon_list[i].name==weapon){
				MAX_HP+=((MAX_HP/100)*weapon_list[i].HP_MODIFIER);
				break;
			}
		}
	}
	
	if (armour!=""){
		for (uint16_t i=0; i<armour_list.size();i++){
			if (armour_list[i].name==armour){
				MAX_HP+=((MAX_HP/100)*armour_list[i].HP_MODIFIER);
				break;
			}
		}
	}
	
	if (trinket!=""){
		for (uint16_t i=0; i<trinket_list.size();i++){
			if (trinket_list[i].name==trinket){
				MAX_HP+=((MAX_HP/100)*trinket_list[i].HP_MODIFIER);
				break;
			}
		}
	}
}

void player_character::CALC_MAX_CARRY(std::vector<Weapon> &weapon_list, std::vector<Armour> &armour_list, std::vector<Trinket> &trinket_list){
	
	int STR_MODIFIER=0;
	
	if (weapon!=""){
		for (uint16_t i=0; i<weapon_list.size();i++){
			if (weapon_list[i].name==weapon){
				STR_MODIFIER+=weapon_list[i].STR_MODIFIER;
				break;
			}
		}
	}
	
	if (armour!=""){
		for (uint16_t i=0; i<armour_list.size();i++){
			if (armour_list[i].name==armour){
				STR_MODIFIER+=armour_list[i].STR_MODIFIER;
				break;
			}
		}
	}
	
	if (trinket!=""){
		for (uint16_t i=0; i<trinket_list.size(); i++){
			if (trinket_list[i].name==trinket){
				STR_MODIFIER+=trinket_list[i].STR_MODIFIER;
				break;
			}
		}
	}
	
	MAX_CARRY=(STR+STR_MODIFIER)*5;
	
	if (weapon!=""){
		for (uint16_t i=0; i<weapon_list.size();i++){
			if (weapon_list[i].name==weapon){
				MAX_CARRY+=((MAX_CARRY/100)*weapon_list[i].CARRY_MODIFIER);
				break;
			}
		}
	}
	
	if (armour!=""){
		for (uint16_t i=0; i<armour_list.size();i++){
			if (armour_list[i].name==armour){
				MAX_CARRY+=((MAX_CARRY/100)*armour_list[i].CARRY_MODIFIER);
				break;
			}
		}
	}
	
	if (trinket!=""){
		for (uint16_t i=0; i<trinket_list.size();i++){
			if (trinket_list[i].name==trinket){
				MAX_CARRY+=((MAX_CARRY/100)*trinket_list[i].CARRY_MODIFIER);
				break;
			}
		}
	}
}

void player_character::CALC_PROTECTION (std::vector<Weapon> &weapon_list, std::vector<Armour> &armour_list, std::vector<Trinket> &trinket_list){

	protection = base_protection;
	
	if (weapon!=""){
		for (uint16_t i=0; i<weapon_list.size();i++){
			if (weapon_list[i].name==weapon){
				protection+=weapon_list[i].PROTECTION;
				break;
			}
		}
	}
	
	if (armour!=""){
		for (uint16_t i=0; i<armour_list.size();i++){
			if (armour_list[i].name==armour){
				protection+=armour_list[i].PROTECTION;
				break;
			}
		}
	}
	
	/*if (trinket!=""){
		for (uint16_t i=0; i<trinket_list.size(); i++){
			if (trinket_list[i].name==trinket){
				PROTECTION+=trinket_list[i].PROTECTION;
				break;
			}
		}
	}*/
}

void player_character::CALC_ATTACK (std::vector<Weapon> &weapon_list, std::vector<Armour> &armour_list, std::vector<Trinket> &trinket_list){

	int STR_MODIFIER=0;
	int ATTACK_MODIFIER=0;
	
	if (weapon!=""){
		for (uint16_t i=0; i<weapon_list.size();i++){
			if (weapon_list[i].name==weapon){
				STR_MODIFIER+=weapon_list[i].STR_MODIFIER;
				ATTACK_MODIFIER=weapon_list[i].ATTACK_POWER;
				break;
			}
		}
	}
	
	if (armour!=""){
		for (uint16_t i=0; i<armour_list.size();i++){
			if (armour_list[i].name==armour){
				STR_MODIFIER+=armour_list[i].STR_MODIFIER;
				break;
			}
		}
	}
	
	if (trinket!=""){
		for (uint16_t i=0; i<trinket_list.size(); i++){
			if (trinket_list[i].name==trinket){
				STR_MODIFIER+=trinket_list[i].STR_MODIFIER;
				break;
			}
		}
	}

	attack=((STR+STR_MODIFIER)/2)+ATTACK_MODIFIER;

}

void player_character::MOVE(direction inputDirection){

	switch (inputDirection){
	
	case direction::left:
			
				current_position.x--;
				draw_position.x--; break;
			
	case direction::right:
	
			current_position.x++;
			draw_position.x++; break;
			
	case direction::up:
	
			current_position.y--;
			draw_position.y--; break;
			
	case direction::down:
	
			current_position.y++;
			draw_position.y++; break;
			
	}
	
	ap--;
	
}


void player_character::ADD_ABILITY (Ability* ability)
{
	ability_list.push_back(ability);
}

int player_character::USE_ABILITY(int i)
{
	if (ap>=ability_list[i]->cost)
	{
		ability_list[i]->effect(*this);
		ap-=ability_list[i]->cost;
	}
}